Email Commander
===============

[![email-commander version](https://img.shields.io/pypi/v/email-commander.svg)](https://pypi.python.org/pypi/email-commander)
[![email-commander license](https://img.shields.io/pypi/l/email-commander.svg)](https://pypi.python.org/pypi/email-commander)
[![email-commander python compatibility](https://img.shields.io/pypi/pyversions/email-commander.svg)](https://pypi.python.org/pypi/email-commander)
[![Downloads](https://static.pepy.tech/personalized-badge/email-commander?period=total&units=international_system&left_color=grey&right_color=yellow&left_text=Downloads)](https://pepy.tech/project/email-commander)
[![say thanks!](https://img.shields.io/badge/Say%20Thanks-!-1EAEDB.svg)](https://saythanks.io/to/marcin%40urzenia.net)

`Email Commander` allows you to manage any host just by sending emails.

If you like this tool, just [say thanks](https://saythanks.io/to/marcin%40urzenia.net).

Current stable version
----------------------

0.0.1

Features
--------

* It's all Python!

Installation
------------

`Email Commander` should work on any POSIX platform where [Python](http://python.org)
is available, it means Linux, MacOS/OSX etc.

Simplest way is to use Python's built-in package system:

    python3 -m pip install Email Commander

You can also use [pipx](https://pipxproject.github.io/pipx/) if you don't want to
mess with system packages and install `Email Commander` in virtual environment:

    pipx install email-commander

Voila!

Python version
--------------

`Email Commander` is tested against Python 3.7+. Older Python versions may work, or may not.

How to use
----------


Help!
-----

I'm backend developer, not a frontend guy nor designer... And project requires some logo and/or icon.
If you're able to prepare some for this project, do not hesitate to [mail me](mailto:marcin@urzenia.net) :)

Also, if you have an idea how to enhance `Email Commander`, [please fill the ticket](https://github.com/msztolcman/email-commander/issues).
Every idea, every feature request can help you, me and others!


Authors
-------

* Marcin Sztolcman ([marcin@urzenia.net](mailto:marcin@urzenia.net))

Contact
-------

If you like or dislike this software, please do not hesitate to tell me about
this me via email ([marcin@urzenia.net](mailto:marcin@urzenia.net)).

If you find bug or have an idea to enhance this tool, please use GitHub's
[issues](https://github.com/msztolcman/email-commander/issues).

ChangeLog
---------

### v0.0.1

* initial
